from django.http import HttpResponse
from django.shortcuts import render
from django.urls import resolve

from contracts.models import Contract


class InterruptMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        resolver_match = resolve(request.path_info)

        # You can now access the view name and other details
        view_name = resolver_match.view_name

        # Check if the INTERRUPT_REQUESTS setting is enabled
        if (
            Contract.settings.is_closed
            and view_name.startswith("admin")
            and view_name not in ("admin:login",)
        ):
            # Interrupt the request by returning a response
            return render(
                request,
                "closed.html",
                {"closed_message": Contract.settings.closed_message},
            )

        # If not interrupted, continue with the request
        response = self.get_response(request)
        return response
